Package: highcharter
Type: Package
Version: 0.9.5
Title: A Wrapper for the 'Highcharts' Library
Description: A wrapper for the 'Highcharts' library including
    shortcut functions to plot R objects. 'Highcharts'
    <https://www.highcharts.com/> is a charting library offering
    numerous chart types with a simple configuration syntax.
Authors@R: c(
  person("Joshua", "Kunst", role = c("aut", "cre"), email = "jbkunst@gmail.com"),
  person("Nuno", "Agostinho", role = c("ctb"), comment  = "hchart.survfit, densities and hc_add_series_scatter"),
  person("Danton", "Noriega", role = c("ctb"), comment  = "hcaes_"),
  person("Martin John ", "Hadley", role = c("ctb"), comment  = "hc_add_event_point improvement"),
  person("Eduardo", "Flores", role = c("ctb"), comment  = "First version hc_add_series_df_tidy"),
  person("Dean", "Kilfoyle", role = c("ctb"), comment  = "First version hc_add_series_boxplot"),
  person("Adline", "Dsilva", role = c("ctb"), comment  = "First version Matrix heatmap"),
  person("Kamil", "Slowikowski", role = c("ctb"), comment = c(ORCID = "0000-0002-2843-6370")),
  person("Christian", "Minich", role = c("ctb"), comment  = "hcaes mutate_mapping improvement"),
  person("Jonathan", "Armond", role = c("ctb"), comment = "mutate_mapping bugfix"),
  person("David", "Breuer", role = c("ctb"), comment = "download_map_data quiet parameter"),
  person("Mauricio", "Vargas", role = c("ctb"), comment = "tests and gh-actions"),
  person("Michael", "Yan", role = c("ctb"), comment = "Motivational example for treemap/sunburst data helper"),
  person("Bart", "Oortwijn", role = c("ctb"), comment = "rjson option, hc_add_yAxis, and GH issues collaborator"),
  person("Paul", "Campbell", role = c("ctb"), comment = "additional proxy methods")
  )
URL: https://jkunst.com/highcharter/,
        https://github.com/jbkunst/highcharter
BugReports: https://github.com/jbkunst/highcharter/issues
License: MIT + file LICENSE
RoxygenNote: 7.3.3
Encoding: UTF-8
Depends: R (>= 2.10)
Imports: htmlwidgets, magrittr, purrr, rlist, assertthat, zoo, dplyr
        (>= 1.0.0), tibble (>= 1.1), stringr (>= 1.3.0), broom, xts,
        quantmod, tidyr, htmltools, jsonlite, igraph, lubridate, yaml,
        rlang (>= 0.1.1), rjson
Suggests: knitr, rmarkdown, survival, ggplot2, httr, viridisLite,
        shiny, MASS, gapminder, forecast, geojsonio, testthat, covr,
        spelling
LazyData: true
Language: en-US
NeedsCompilation: no
Packaged: 2026-04-21 18:09:41 UTC; kupietz
Author: Joshua Kunst [aut, cre],
  Nuno Agostinho [ctb] (hchart.survfit, densities and
    hc_add_series_scatter),
  Danton Noriega [ctb] (hcaes_),
  Martin John Hadley [ctb] (hc_add_event_point improvement),
  Eduardo Flores [ctb] (First version hc_add_series_df_tidy),
  Dean Kilfoyle [ctb] (First version hc_add_series_boxplot),
  Adline Dsilva [ctb] (First version Matrix heatmap),
  Kamil Slowikowski [ctb] (ORCID:
    <https://orcid.org/0000-0002-2843-6370>),
  Christian Minich [ctb] (hcaes mutate_mapping improvement),
  Jonathan Armond [ctb] (mutate_mapping bugfix),
  David Breuer [ctb] (download_map_data quiet parameter),
  Mauricio Vargas [ctb] (tests and gh-actions),
  Michael Yan [ctb] (Motivational example for treemap/sunburst data
    helper),
  Bart Oortwijn [ctb] (rjson option, hc_add_yAxis, and GH issues
    collaborator),
  Paul Campbell [ctb] (additional proxy methods)
Maintainer: Joshua Kunst <jbkunst@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 09:38:59 UTC
Built: R 4.6.0; ; 2026-04-30 07:03:01 UTC; unix
