# Generated by roxygen2: do not edit by hand

S3method(hc_add_series,character)
S3method(hc_add_series,data.frame)
S3method(hc_add_series,default)
S3method(hc_add_series,density)
S3method(hc_add_series,factor)
S3method(hc_add_series,forecast)
S3method(hc_add_series,geo_json)
S3method(hc_add_series,geo_list)
S3method(hc_add_series,lm)
S3method(hc_add_series,loess)
S3method(hc_add_series,numeric)
S3method(hc_add_series,ohlc)
S3method(hc_add_series,ts)
S3method(hc_add_series,xts)
S3method(hchart,acf)
S3method(hchart,character)
S3method(hchart,data.frame)
S3method(hchart,default)
S3method(hchart,density)
S3method(hchart,dist)
S3method(hchart,ets)
S3method(hchart,factor)
S3method(hchart,forecast)
S3method(hchart,histogram)
S3method(hchart,igraph)
S3method(hchart,list)
S3method(hchart,matrix)
S3method(hchart,mforecast)
S3method(hchart,mts)
S3method(hchart,numeric)
S3method(hchart,prcomp)
S3method(hchart,princomp)
S3method(hchart,stl)
S3method(hchart,survfit)
S3method(hchart,tibble)
S3method(hchart,ts)
S3method(hchart,xts)
export("%>%")
export(JS)
export(color_classes)
export(color_stops)
export(colorize)
export(create_axis)
export(create_yaxis)
export(data_to_boxplot)
export(data_to_hierarchical)
export(data_to_sankey)
export(datetime_to_timestamp)
export(df_to_annotations_labels)
export(download_map_data)
export(dt_tstp)
export(export_hc)
export(fa_icon)
export(fa_icon_mark)
export(get_data_from_map)
export(hc_add_annotation)
export(hc_add_annotations)
export(hc_add_dependency)
export(hc_add_dependency_fa)
export(hc_add_event_point)
export(hc_add_event_series)
export(hc_add_series)
export(hc_add_series_list)
export(hc_add_series_map)
export(hc_add_theme)
export(hc_add_yAxis)
export(hc_annotations)
export(hc_boost)
export(hc_caption)
export(hc_chart)
export(hc_colorAxis)
export(hc_colors)
export(hc_credits)
export(hc_drilldown)
export(hc_elementId)
export(hc_exporting)
export(hc_labels)
export(hc_legend)
export(hc_loading)
export(hc_mapNavigation)
export(hc_motion)
export(hc_navigator)
export(hc_pane)
export(hc_plotOptions)
export(hc_rangeSelector)
export(hc_responsive)
export(hc_rm_series)
export(hc_scrollbar)
export(hc_series)
export(hc_size)
export(hc_subtitle)
export(hc_theme)
export(hc_theme_538)
export(hc_theme_alone)
export(hc_theme_bloom)
export(hc_theme_chalk)
export(hc_theme_darkunica)
export(hc_theme_db)
export(hc_theme_economist)
export(hc_theme_elementary)
export(hc_theme_ffx)
export(hc_theme_flat)
export(hc_theme_flatdark)
export(hc_theme_ft)
export(hc_theme_ggplot2)
export(hc_theme_google)
export(hc_theme_gridlight)
export(hc_theme_handdrawn)
export(hc_theme_hcrt)
export(hc_theme_merge)
export(hc_theme_monokai)
export(hc_theme_null)
export(hc_theme_sandsignika)
export(hc_theme_smpl)
export(hc_theme_sparkline)
export(hc_theme_sparkline_vb)
export(hc_theme_superheroes)
export(hc_theme_tufte)
export(hc_theme_tufte2)
export(hc_title)
export(hc_tooltip)
export(hc_xAxis)
export(hc_xAxis_multiples)
export(hc_yAxis)
export(hc_yAxis_multiples)
export(hc_zAxis)
export(hc_zAxis_multiples)
export(hcaes)
export(hcaes_)
export(hcaes_string)
export(hcboxplot)
export(hchart)
export(hciconarray)
export(hcmap)
export(hcparcords)
export(hcpxy_add_point)
export(hcpxy_add_series)
export(hcpxy_loading)
export(hcpxy_redraw)
export(hcpxy_remove_point)
export(hcpxy_remove_series)
export(hcpxy_set_data)
export(hcpxy_update)
export(hcpxy_update_point)
export(hcpxy_update_series)
export(hcspark)
export(hctreemap)
export(hctreemap2)
export(hex_to_rgba)
export(highchart)
export(highchart2)
export(highchartOutput)
export(highchartOutput2)
export(highchartOutputZ)
export(highchartProxy)
export(highcharts_demo)
export(highchartzero)
export(hw_grid)
export(is.hexcolor)
export(is.highchart)
export(list_parse)
export(list_parse2)
export(mutate_mapping)
export(renderHighchart)
export(renderHighchart2)
export(renderHighchartZ)
export(str_to_id)
export(tags)
export(tooltip_chart)
export(tooltip_table)
importFrom(assertthat,are_equal)
importFrom(assertthat,assert_that)
importFrom(assertthat,on_failure)
importFrom(broom,augment)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,arrange_)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,count_)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,do)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,filter_)
importFrom(dplyr,glimpse)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_all)
importFrom(dplyr,group_by_at)
importFrom(dplyr,group_nest)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_)
importFrom(dplyr,mutate_at)
importFrom(dplyr,mutate_if)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,rename_all)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,select_)
importFrom(dplyr,summarise)
importFrom(dplyr,tbl_df)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(dplyr,vars)
importFrom(grDevices,boxplot.stats)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,n2mfrow)
importFrom(graphics,hist)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(jsonlite,toJSON)
importFrom(lubridate,is.Date)
importFrom(magrittr,"%>%")
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,map_df)
importFrom(purrr,map_if)
importFrom(purrr,map_lgl)
importFrom(purrr,pmap_chr)
importFrom(purrr,reduce)
importFrom(purrr,transpose)
importFrom(quantmod,is.OHLC)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,enexprs)
importFrom(rlang,is_missing)
importFrom(rlang,parse_quo)
importFrom(rlang,syms)
importFrom(rlist,list.merge)
importFrom(rlist,list.parse)
importFrom(stats,complete.cases)
importFrom(stats,ecdf)
importFrom(stats,qnorm)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,time)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_glue)
importFrom(stringr,str_remove)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_to_title)
importFrom(stringr,str_trim)
importFrom(tibble,has_name)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tibble,tibble_)
importFrom(tidyr,gather)
importFrom(tidyr,unite)
importFrom(tidyr,unite_)
importFrom(tidyr,unnest)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,hasName)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(xts,is.xts)
importFrom(yaml,yaml.load_file)
importFrom(zoo,as.Date)
