% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helpers.R
\name{highcharts_demo}
\alias{highcharts_demo}
\title{Chart a demo for testing themes}
\usage{
highcharts_demo()
}
\description{
Chart a demo for testing themes
}
\examples{

highcharts_demo()
}
