% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/highcharter.R
\name{highchartOutput}
\alias{highchartOutput}
\alias{highchartOutput2}
\alias{highchartOutputZ}
\title{Widget output function for use in Shiny}
\usage{
highchartOutput(outputId, width = "100\%", height = "400px")

highchartOutput2(outputId, width = "100\%", height = "400px")

highchartOutputZ(outputId, width = "100\%", height = "400px")
}
\arguments{
\item{outputId}{The name of the input.}

\item{width}{A numeric input in pixels.}

\item{height}{A numeric input in pixels.}
}
\description{
Widget output function for use in Shiny
}
